@@ -3,11 +3,11 @@ package POE::Component::WWW::Search::Mininova;
 use 5.008008;
 use strict;
 use warnings;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use WWW::Search::Mininova;
 
-use POE 0.38 qw(Wheel::Run  Filter::Line  Filter::Reference);
+use POE qw(Wheel::Run  Filter::Line  Filter::Reference);
 use Carp;
 
 
@@ -22,12 +22,6 @@ sub spawn {
     delete $args{options}
         unless ref $args{options} eq 'HASH';
 
-    eval {
-        require WWW::Search::Mininova;
-    };
-    croak "Failed to load WWW::Search::Mininova ($@)"
-        if $@;
-
     my $self = bless \%args, $class;
 
     $self->{session_id} = POE::Session->create(
@@ -520,15 +514,48 @@ L<POE> L<WWW::Search::Mininova>
 
 =head1 AUTHOR
 
-Zoffix Znet, E<lt>zoffix@cpan.orgE<gt>
+Zoffix Znet, C<< <zoffix at cpan.org> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 BUGS
 
-Copyright (C) 2008 by Zoffix Znet
+Please report any bugs or feature requests to C<bug-poe-component-www-search-mininova at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POE-Component-WWW-Search-Mininova>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc POE::Component::WWW::Search::Mininova
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POE-Component-WWW-Search-Mininova>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/POE-Component-WWW-Search-Mininova>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/POE-Component-WWW-Search-Mininova>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/POE-Component-WWW-Search-Mininova>
+
+=back
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2008 Zoffix Znet, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 
 =cut
